<template>
  <div class="app">
    <!-- 主要内容区 -->
    <div class="main-content">
      <!-- 左侧视频预览 -->
      <div class="video-container">
        <button class="back-button" @click="goback">
          <i class="fas fa-arrow-left"></i>
          返回多画面
        </button>
        
        <div v-if="isLoading" class="loading-overlay">
          <div class="loading-spinner"></div>
          <p>正在加载视频流...</p>
        </div>
        
        <div v-if="stream.error" class="error-overlay">
          <i class="fas fa-exclamation-triangle"></i>
          <p>{{ stream.error }}</p>
          <button class="retry-button" @click="created()">重试</button>
        </div>
        <div class="video-wrapper">
          <M3U8Player 
            :url="stream.url"
            :deviceId="stream.deviceId"
            :deviceName="stream.deviceName"
            :deviceType="stream.deviceType"
            :hasAudio="true"
            @toggleControlPanel="toggleControlPanel"
            ref="m3u8Player"
          />
        </div>
      </div>
      <!-- 右侧控制面板 -->
      <div class="control-panel" v-show="showControlPanel">
        <div class="control-section">
          <!-- 云台控制 -->
          <div class="ptz-control">
            <h3>云台控制</h3>
            <div class="direction-circle">
              <div class="direction-btn btn-up" 
                   @click="controlPTZ('UP')">
                <i class="el-icon-caret-top"></i>
              </div>
              <div class="direction-btn btn-right" 
                   @click="controlPTZ('RIGHT')">
                <i class="el-icon-caret-right"></i>
              </div>
              <div class="direction-btn btn-down" 
                   @click="controlPTZ('DOWN')">
                <i class="el-icon-caret-bottom"></i>
              </div>
              <div class="direction-btn btn-left" 
                   @click="controlPTZ('LEFT')">
                <i class="el-icon-caret-left"></i>
              </div>
              <div class="direction-btn btn-stop" 
                   @click="controlPTZ('STOP')">
              <svg-icon name="stop" class="info-icon" />
                <!-- <i class="el-icon-video-pause"></i> -->
              </div>
            </div>
            <!-- <div class="speed-control">
              <el-slider
                v-model="ptzSpeed"
                :min="1"
                :max="7"
                :step="1"
                @change="setPtzSpeed"
                :marks="{
                  1: '慢',
                  4: '中',
                  7: '快'
                }"
              ></el-slider>
            </div> -->
            <div class="zoom-buttons">
              <div class="zoom-btn" title="聚焦" 
                   @click="controlPTZ('FOCUS_NEAR')">
                <svg-icon name="聚焦" class="info-icon" />
              </div>
              <div style="display: flex; gap: 12px;">
                <div class="zoom-btn" title="放大" 
                     @click="controlPTZ('IN')">
                  <svg-icon name="放大" class="info-icon" />
                </div>
                <div class="zoom-btn" title="缩小" 
                     @click="controlPTZ('OUT')">
                  <svg-icon name="缩小" class="info-icon" />
                </div>
              </div>
              
            </div>
          </div>
          <!-- 预设点位 -->
          <div class="preset-control">
            <div class="preset-header">
                <h3>预设点位</h3>
                <el-button class="btn-add" type="primary" size="mini" @click="showAddPresetVisible = true">
                  添加预设点
                </el-button>
              </div>
            <div class="preset-table-wrapper">
              <table class="preset-table">
                <thead>
                  <tr>
                    <th class="w-16">序号</th>
                    <th>预设点名称</th>
                    <th class="w-32 text-center">操作</th>
                  </tr>
                </thead>
                <tbody>
                  <template v-if="presets && presets.length > 0">
                    <tr v-for="(preset, index) in presets" :key="index">
                      <td class="text-center">{{ index + 1 }}</td>
                      <td>{{ preset.name }}</td>
                      <td>
                        <div class="preset-actions">
                          <!-- <button class="!rounded-button btn-goto" title="调用" @click="gotoPreset(preset)">
                            <i class="fas fa-location-arrow"></i>
                          </button>
                          <button class="!rounded-button btn-edit" title="编辑" @click="editPreset(preset)">
                            <i class="fas fa-edit"></i>
                          </button> -->
                          <el-button type="text" @click="deletePreset(preset)">
                            删除
                          </el-button>
                        </div>
                      </td>
                    </tr>
                  </template>
                  <template v-else>
                    <tr>
                      <td colspan="3" class="empty-state">
                        <div class="empty-content">
                          <i class="fas fa-map-marker-alt empty-icon"></i>
                          <p>暂无预设点位</p>
                        </div>
                      </td>
                    </tr>
                  </template>
                </tbody>
              </table>
              <!-- 分页区域，如果将来需要 -->
              <div class="pagination-container" v-if="presets && presets.length > 5">
                <div class="pagination">
                  <button class="pagination-btn" disabled>
                    <i class="fas fa-chevron-left"></i>
                  </button>
                  <button class="pagination-btn active">1</button>
                  <button class="pagination-btn">2</button>
                  <button class="pagination-btn">
                    <i class="fas fa-chevron-right"></i>
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
    <el-dialog
      title="提示"
      :visible.sync="showAddPresetVisible"
      width="30%"
      center>
      <span>确认将当前镜头视角添加为预置点吗？添加成功后，可在 [ 预置点 ] 中查看及调用</span>
      <span slot="footer" class="dialog-footer">
        <el-button @click="showAddPresetVisible = false">取 消</el-button>
        <el-button type="primary" @click="handleAddPreset">确 定</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import M3U8Player from '@/components/HuaweiVideo/M3U8Player.vue';
import { ptzController } from '@/utils/ptzControl'

export default {
  name: 'App',
  props: {
    camera: {
      type: Object,
      required: true
    },
  },
  components: {
    M3U8Player
  },
  data() {
    return {
      showAddPresetVisible: false,
      stream: {
          url: '',
          deviceId: '',
          channelId: '',
          deviceName: '摄像头',
          deviceType: 'IPC',
          status: 'loading',
          error: null
      },
      isLoading: true,
      ptzSpeed: 4, // 云台速度，默认为4
      showControlPanel: true, // 控制右侧面板的显示/隐藏
      presets: [
        { name: '大门入口', id: 1 },
        { name: '停车场', id: 2 },
        { name: '后门通道', id: 3 },
        { name: '办公区域', id: 4 }
      ]
    };
  },
  
  async created() {
      console.log('this.camera', this.camera)
      this.isLoading = true;
      if (this.camera) {
        this.stream.url = this.camera.stream;
        this.stream.deviceId = this.camera.deviceId;
        this.stream.channelId = this.camera.channelId;
        this.isLoading = false;
      }
  },
  methods: {
    goback() {
      this.$emit('goback', true);
    },
    handleAddPreset() {

    },
    /**
     * 控制云台方向
     * @param {string} action - 控制动作：'UP'|'DOWN'|'LEFT'|'RIGHT'|'STOP'|'FOCUS_NEAR'|'IN'|'OUT'
     */
    controlPTZ(action) {
      ptzController.startPtzControl({
        direction: action.toUpperCase(),
        stream: this.stream,
        onSuccess: () => {
          console.log('云台控制成功:', action);
        },
        onError: (error) => {
          console.error('云台控制失败:', error);
          this.$message.error(error.message);
        }
      });
    },
    /**
     * 设置云台速度
     * @param {number} speed - 速度值(1-7)
     */
    setPtzSpeed(speed) {
      ptzController.setPtzSpeed(speed);
    },

    /**
     * 获取当前云台速度
     * @returns {number} 当前速度值
     */
    getPtzSpeed() {
      return ptzController.getPtzSpeed();
    },

    /**
     * 调用预设点位
     * @param {Object} preset - 预设点位对象
     */
    gotoPreset(preset) {
      try {
        console.log('Goto preset:', preset);
        // TODO: 实现调用预设点位的逻辑
      } catch (error) {
        console.error('调用预设点位失败:', error);
        // TODO: 添加错误提示
      }
    },

    /**
     * 编辑预设点位
     * @param {Object} preset - 预设点位对象
     */
    editPreset(preset) {
      try {
        console.log('Edit preset:', preset);
        // TODO: 实现编辑预设点位的逻辑
      } catch (error) {
        console.error('编辑预设点位失败:', error);
        // TODO: 添加错误提示
      }
    },

    /**
     * 删除预设点位
     * @param {Object} preset - 预设点位对象
     */
    deletePreset(preset) {
      try {
        console.log('Delete preset:', preset);
        // TODO: 实现删除预设点位的逻辑
      } catch (error) {
        console.error('删除预设点位失败:', error);
        // TODO: 添加错误提示
      }
    },

    /**
     * 显示添加预设点位对话框
     */
    
    toggleControlPanel() {
      this.showControlPanel = !this.showControlPanel;
    }
  }
};
</script>
<style scoped>
.app {
  min-height: 100vh;
  background-color: #f9fafb;
}

.header {
  background-color: #2563eb;
  color: white;
  height: 48px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 0 16px;
}

.header-left {
  display: flex;
  align-items: center;
  gap: 16px;
}

.header-left h1 {
  font-size: 18px;
  font-weight: 500;
}

.header-right {
  display: flex;
  align-items: center;
  gap: 16px;
}

.header-right span {
  font-size: 14px;
}

.header-right i {
  font-size: 20px;
}

.main-content {
  display: flex;
  height: calc(100vh - 48px);
}

.video-container {
  flex: 1;
  padding: 24px;
  display: flex;
  flex-direction: column;
  position: relative;
}

.back-button {
  position: absolute;
  top: 24px;
  left: 24px;
  z-index: 10;
  background-color: rgba(37, 99, 235, 0.9);
  color: white;
  padding: 8px 16px;
  font-size: 14px;
  border-radius: 8px;
  border: none;
  cursor: pointer;
  display: flex;
  align-items: center;
  gap: 8px;
  transition: all 0.2s ease;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.2);
}

.back-button:hover {
  background-color: rgba(29, 78, 216, 0.9);
  transform: translateY(-1px);
}

.back-button:active {
  transform: translateY(0);
}

.back-button i {
  font-size: 14px;
}

.loading-overlay,
.error-overlay {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: rgba(0, 0, 0, 0.7);
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  color: white;
  z-index: 5;
}

.loading-spinner {
  width: 40px;
  height: 40px;
  border: 4px solid rgba(255, 255, 255, 0.3);
  border-radius: 50%;
  border-top-color: #2563eb;
  animation: spin 1s ease-in-out infinite;
}

@keyframes spin {
  to { transform: rotate(360deg); }
}

.error-overlay i {
  font-size: 40px;
  color: #ef4444;
  margin-bottom: 16px;
}

.retry-button {
  margin-top: 16px;
  padding: 8px 16px;
  background-color: #2563eb;
  color: white;
  border: none;
  border-radius: 4px;
  cursor: pointer;
  transition: background-color 0.2s;
}

.retry-button:hover {
  background-color: #1d4ed8;
}

.video-wrapper {
  position: relative;
  width: 100%;
  height: 100%;
  background-color: #0f172a;
  border-radius: 12px;
  overflow: hidden;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
  border: 1px solid rgba(255, 255, 255, 0.1);
}

.video-wrapper img {
  width: 100%;
  height: 100%;
  object-fit: cover;
}

.video-controls {
  position: absolute;
  bottom: 20px;
  right: 20px;
  display: flex;
  gap: 12px;
}

.btn-fullscreen {
  background-color: rgba(37, 99, 235, 0.9);
  color: white;
  padding: 8px 16px;
  font-size: 14px;
  border-radius: 8px;
  backdrop-filter: blur(4px);
  transition: all 0.2s ease;
  display: flex;
  align-items: center;
  gap: 8px;
  border: 1px solid rgba(255, 255, 255, 0.2);
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.2);
}

.btn-fullscreen:hover {
  background-color: rgba(29, 78, 216, 0.9);
  transform: translateY(-1px);
}

.btn-fullscreen:active {
  transform: translateY(0);
}

.btn-fullscreen i {
  font-size: 14px;
}

.control-panel {
  width: 360px;
  background-color: white;
  padding: 24px;
  border-left: 1px solid #e5e7eb;
  box-shadow: -2px 0 8px rgba(0, 0, 0, 0.05);
  display: flex;
  flex-direction: column;
  gap: 32px;
  overflow-y: auto;
}

.control-section {
  display: flex;
  flex-direction: column;
  gap: 32px;
}

.ptz-control h3,
.zoom-control h3,
.preset-control h3 {
  color: #1f2937;
  font-weight: 600;
  margin-bottom: 16px;
  font-size: 16px;
  display: flex;
  align-items: center;
  gap: 8px;
}

.ptz-control h3::before,
.zoom-control h3::before,
.preset-control h3::before {
  content: '';
  display: block;
  width: 4px;
  height: 16px;
  background-color: #2563eb;
  border-radius: 2px;
}

.direction-circle {
  position: relative;
  width: 200px;
  height: 200px;
  margin: 0 auto;
  background: #d5dbe1ab;
  border-radius: 50%;
  padding: 8px;
}

.direction-btn {
  position: absolute;
  width: 44px;
  height: 44px;
  background-color: white;
  border: 1px solid #e2e8f0;
  border-radius: 50% !important;
  /* transition: all 0.2s ease; */
  display: flex;
  align-items: center;
  justify-content: center;
  color: #475569;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}

.center-btn {
  width: 80px;
  height: 80px;
}

.direction-btn:hover {
  background-color: #73b2f0;
  box-shadow: 0 4px 6px rgba(0, 0, 0, 0.05);
  color: #ffffff;
}

.direction-btn:active {
  /* transform: scale(1); */
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}

.direction-btn i {
  font-size: 16px;
}

.btn-up {
  top: 8px;
  left: 50%;
  transform: translateX(-50%);
}

.btn-right {
  right: 8px;
  top: 50%;
  transform: translateY(-50%);
}

.btn-down {
  bottom: 8px;
  left: 50%;
  transform: translateX(-50%);
}

.btn-left {
  left: 8px;
  top: 50%;
  transform: translateY(-50%);
}

.btn-stop {
  height: 80px;
  width: 80px;
  left: 50%;
  top: 50%;
  transform: translate(-50%, -50%);
}

.zoom-buttons {
  display: flex;
  gap: 12px;
  padding: 8px;
  margin-top: 10px;
  background: #f8fafc;
  border-radius: 12px;
  justify-content: space-between;
}

.zoom-btn {
  width: 44px;
  height: 44px;
  background-color: white;
  border: 1px solid #e2e8f0;
  border-radius: 50% !important;
  transition: all 0.2s ease;
  display: flex;
  align-items: center;
  justify-content: center;
  color: #475569;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}

.zoom-btn:hover {
  background-color: #f1f5f9;
  transform: scale(1.1);
  box-shadow: 0 4px 6px rgba(0, 0, 0, 0.05);
  color: #2563eb;
}

.zoom-btn:active {
  transform: scale(1);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}

.zoom-btn i {
  font-size: 16px;
}

.preset-header {
  display: flex;
  justify-content: space-between;
  align-items: center;
  margin-bottom: 16px;
}

.btn-add {
  background-color: #2563eb;
  color: white;
  padding: 8px 16px;
  font-size: 14px;
  border-radius: 8px !important;
  transition: all 0.2s ease;
  display: flex;
  align-items: center;
  gap: 8px;
  font-weight: 500;
}

.btn-add:hover {
  background-color: #1d4ed8;
  transform: translateY(-1px);
  box-shadow: 0 4px 6px rgba(37, 99, 235, 0.2);
}

.btn-add:active {
  transform: translateY(0);
}

.btn-add i {
  font-size: 14px;
}

.preset-table-wrapper {
  background: #f8fafc;
  border-radius: 12px;
  padding: 12px;
  overflow-x: auto;
}

.preset-table {
  width: 100%;
  border-collapse: separate;
  border-spacing: 0;
  font-size: 14px;
}

.preset-table th {
  background-color: #f1f5f9;
  color: #1f2937;
  font-weight: 600;
  text-align: left;
  padding: 12px;
  border-bottom: 2px solid #e2e8f0;
}

.preset-table th:first-child {
  border-top-left-radius: 8px;
}

.preset-table th:last-child {
  border-top-right-radius: 8px;
}

.preset-table td {
  padding: 12px;
  border-bottom: 1px solid #e2e8f0;
  color: #334155;
}

.preset-table tbody tr {
  background-color: white;
  transition: all 0.2s ease;
}

.preset-table tbody tr:hover {
  background-color: #f8fafc;
}

.preset-table tbody tr:last-child td {
  border-bottom: none;
}

.preset-table tbody tr:last-child td:first-child {
  border-bottom-left-radius: 8px;
}

.preset-table tbody tr:last-child td:last-child {
  border-bottom-right-radius: 8px;
}

/* 空状态样式 */
.empty-state {
  padding: 40px 20px !important;
  text-align: center;
}

.empty-content {
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 12px;
}

.empty-icon {
  font-size: 24px;
  color: #94a3b8;
  margin-bottom: 4px;
}

.empty-content p {
  color: #64748b;
  font-size: 14px;
  margin: 0;
}

.btn-add-empty {
  margin-top: 8px;
  padding: 8px 16px;
  background-color: #eff6ff;
  color: #2563eb;
  font-size: 14px;
  display: flex;
  align-items: center;
  gap: 8px;
  transition: all 0.2s ease;
}

.btn-add-empty:hover {
  background-color: #dbeafe;
  transform: translateY(-1px);
}

.btn-add-empty:active {
  transform: translateY(0);
}

/* 分页样式 */
.pagination-container {
  margin-top: 20px;
  display: flex;
  justify-content: center;
}

.pagination {
  display: flex;
  gap: 4px;
  align-items: center;
  background-color: white;
  padding: 4px;
  border-radius: 8px;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.05);
}

.pagination-btn {
  min-width: 32px;
  height: 32px;
  display: flex;
  align-items: center;
  justify-content: center;
  border-radius: 6px;
  font-size: 14px;
  color: #64748b;
  background-color: transparent;
  transition: all 0.2s ease;
  border: none;
}

.pagination-btn:hover:not(:disabled) {
  background-color: #f1f5f9;
  color: #1f2937;
}

.pagination-btn.active {
  background-color: #2563eb;
  color: white;
}

.pagination-btn:disabled {
  opacity: 0.5;
  cursor: not-allowed;
}

.pagination-btn i {
  font-size: 12px;
}

.preset-actions {
  display: flex;
  gap: 8px;
  justify-content: center;
}

.btn-goto,
.btn-edit,
.btn-delete {
  color: #dc2626;
}

.btn-goto {
  color: #2563eb;
  background-color: #eff6ff;
}

.btn-goto:hover {
  background-color: #dbeafe;
  transform: translateY(-1px);
  box-shadow: 0 2px 4px rgba(37, 99, 235, 0.1);
}

.btn-edit {
  color: #4b5563;
  background-color: #f8fafc;
}

.btn-edit:hover {
  background-color: #f1f5f9;
  color: #1f2937;
  transform: translateY(-1px);
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.05);
}

.btn-delete {
  color: #dc2626;
  background-color: #fef2f2;
}

.btn-delete:hover {
  background-color: #fee2e2;
  transform: translateY(-1px);
  box-shadow: 0 2px 4px rgba(220, 38, 38, 0.1);
}

.btn-goto:active,
.btn-edit:active,
.btn-delete:active {
  transform: translateY(0);
  box-shadow: none;
}

.btn-goto i,
.btn-edit i,
.btn-delete i {
  font-size: 12px;
}

.custom-input::-webkit-inner-spin-button,
.custom-input::-webkit-outer-spin-button {
  -webkit-appearance: none;
  margin: 0;
}
::v-deep(.controls) {
    bottom: 0 !important;
    /* opacity: 1  !important; */
}
</style>